==> Rgraphviz_1.3.0.tar.gz: Rgraphviz/man/Ragraph-class.Rd <==
\name{Ragraph-class}
\docType{class}
\alias{Ragraph-class}
\alias{Ragraph}
\alias{laidout}
\alias{agraph}
\alias{nodes}
\alias{boundBox}
\alias{getNodeLocs}
\alias{AgEdge,Ragraph-method}
\alias{agraph,Ragraph-method}
\alias{boundBox,Ragraph-method}
\alias{getNodeLocs,Ragraph-method}
\alias{laidout,Ragraph-method}
\title{Class "Ragraph": A class to handle libgraph representations}
\description{Class \code{Ragraph} is used to handle libgraph
  representations of R graph objects.}
\section{Objects from the Class}{
Objects can be created by calls to the function \code{agopen}.
}
\section{Slots}{
  \describe{
    \item{\code{agraph}:}{Object of class \code{"externalptr"}: A C
      based structure containing the libgraph information}
    \item{\code{laidout}:}{Object of class \code{"logical"}: Whether or
      not this graph has been laid out or not.}
    \item{\code{nodes}:}{Object of class \code{"list"}: A list of
      \code{NodePosition} objects.}
    \item{\code{AgEdge}:}{Object of class \code{"list"}: A list of
      \code{AgEdge} objects.}
    \item{\code{boundBox}:}{Object of class \code{"boundBox"}: Defines
      the bounding box of the plot.}
  }
}

\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "Ragraph")}: A brief summary of
      the contents}
    \item{agraph}{\code{signature(object = "Ragraph")}: Returns the
      external libgraph pointer}
    \item{laidout}{\code{signature(object = "Ragraph")}: Returns the
      \code{laidout} slot}
    \item{nodes}{\code{signature(object = "Ragraph")}: Returns the node
      list.}
    \item{boundBox}{\code{signature(object = "Ragraph")}: Returns the
      bounding box.}
    \item{AgEdge}{\code{signature(object = "Ragraph")}: Returns the edge
      list.}
    \item{getNodeLocs}{\code{signature(object = "Ragraph")}: Returns a
      list with X and Y positions of all nodes, used as a convenience}
  }
}
\author{Jeff Gentry}

\seealso{\code{\link{agopen}}}

\examples{
set.seed(123)
V <- letters[1:10]
M <- 1:4
g1 <- randomGraph(V, M, .2)
z <- agopen(g1,"foo")
z
}
\keyword{classes}

==> Rgraphviz_1.4.0.tar.gz: Rgraphviz/man/Ragraph-class.Rd <==
\name{Ragraph-class}
\docType{class}
\alias{Ragraph-class}
\alias{Ragraph}
\alias{agraph}
\alias{laidout}
\alias{layoutType}
\alias{edgemode}
\alias{boundBox}
\alias{AgEdge,Ragraph-method}
\alias{agraph,Ragraph-method}
\alias{boundBox,Ragraph-method}
\alias{laidout,Ragraph-method}
\alias{layoutType,Ragraph-method}
\alias{edgemode,Ragraph-method}
\alias{AgNode,Ragraph-method}
\alias{getNodeLocs}
\alias{getNodeNames}
\alias{getNodeLabels}
\title{Class "Ragraph": A class to handle libgraph representations}
\description{Class \code{Ragraph} is used to handle libgraph
  representations of R graph objects.}
\section{Objects from the Class}{
Objects can be created by calls to the function \code{agopen}.
}
\section{Slots}{
  \describe{
    \item{\code{agraph}:}{Object of class \code{"externalptr"}: A C
      based structure containing the libgraph information}
    \item{\code{laidout}:}{Object of class \code{"logical"}: Whether or
      not this graph has been laid out or not.}
    \item{\code{layoutType}:}{Object of class \code{"character"}: The
      layout method used for this object}
    \item{\code{edgemode}:}{Object of class \code{"character"}: The
      edgemode for this graph - \dQuote{directed} or \dQuote{undirected}}
    \item{\code{AgNode}:}{Object of class \code{"list"}: A list of
      \code{AgNode} objects.}
    \item{\code{AgEdge}:}{Object of class \code{"list"}: A list of
      \code{AgEdge} objects.}
    \item{\code{boundBox}:}{Object of class \code{"boundBox"}: Defines
      the bounding box of the plot.}
  }
}

\section{Methods}{
  \describe{
    \item{show}{\code{signature(object = "Ragraph")}: A brief summary of
      the contents}
    \item{agraph}{\code{signature(object = "Ragraph")}: Returns the
      external libgraph pointer}
    \item{laidout}{\code{signature(object = "Ragraph")}: Returns the
      \code{laidout} slot}
    \item{nodes}{\code{signature(object = "Ragraph")}: Returns the node
      list.}
    \item{boundBox}{\code{signature(object = "Ragraph")}: Returns the
      bounding box.}
    \item{AgEdge}{\code{signature(object = "Ragraph")}: Returns the edge
      list.}
    \item{AgNode}{\code{signature(object = "Ragraph")}: Returns the node
      list.}
    \item{edgemode}{\code{signature(object = "Ragraph")}: Retrieves the
      edgemode of this object.}
    \item{layoutType}{\code{signature(object = "Ragraph")}: Retrives the
      method used for the layout of this graph.}
  }
}
\author{Jeff Gentry}

\seealso{\code{\link{agopen}}}

\examples{
set.seed(123)
V <- letters[1:10]
M <- 1:4
g1 <- randomGraph(V, M, .2)
z <- agopen(g1,"foo")
z
}
\keyword{classes}
